SELECT 1/aiomysql - Criterion.rs

## SELECT 1/aiomysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0079444 | 0.0082258 | 0.0079108
Mean | 17.592 ms | 17.770 ms | 17.958 ms
Std. Dev. | 789.17 µs | 945.86 µs | 1.0984 ms
Median | 17.244 ms | 17.490 ms | 17.808 ms
MAD | 582.63 µs | 871.56 µs | 1.1104 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.